View Source Eli (eli v0.1.13)
Documentation for Eli.
Summary
Functions
Confirms user email.
Returns the current user data.
Recover password updating it.
Refresh your token session returning a new session token.
Requests password recovery.
Resend email for account confirmation.
Sign in.
Signs user out closing and deleting session.
Checks whether the user is signed in or not.
Unlocks user for making the he/she able to sign in again.
Resend email for account confirmation.
Functions
Confirms user email.
Examples
iex> Eli.confirm("Confirmation token")
202
%{"data" => %{"message" => "account was successfully confirmed"}}
404
%{"errors" => %{"detail" => "Not Found"}}
Returns the current user data.
Examples
iex> Eli.signed_in("JWT session token")
:signed_in
200
%{
"data" => %{
"active" => true,
"email" => "user.name@domain.com",
"id" => "732cf1c2-6299-41fa-8784-e458765743b7",
"language" => "en",
"name" => "Adilson Chacon",
"timezone" => "Europe/London"
}
}
404
%{"errors" => %{"detail" => "Not Found"}},
Recover password updating it.
Examples
iex> Eli.request_password_recovery("Confirmation token")
200
%{"data" => %{"message" => "password was successfully recovered"}}
400
%{"errors" => %{"detail" => "token is invalid"}}
400
%{"errors" => %{"detail" => "password has an invalid format"}}
400
%{"errors" => %{"detail" => "password and confirmation password are different"}}
Refresh your token session returning a new session token.
Examples
iex> Eli.refresh("JWT session token")
200
%{
"data" => %{
"token" => "JWT session token"
}
}
404
%{"errors" => %{"detail" => "Not Found"}},
Requests password recovery.
Examples
iex> Eli.request_password_recovery("Confirmation token")
200
%{"data" => %{"message" => "password recovery was successfully requested"}}
404
%{"errors" => %{"detail" => "Not Found"}}
Resend email for account confirmation.
Examples
iex> Eli.resend_account_confirmation_email("App token", "user@example.com")
200
%{"data" => %{"message" => "account confirmation email was successfully sent"}}
404
%{"errors" => %{"detail" => "Not Found"}}
Sign in.
Examples
iex> Eli.sign_in("app token", "user.email@domain.com", "secret.password")
200
%{
"data" => %{
"token" => "JWT session token"
}
}
400
%{"errors" => %{"detail" => "invalid credentials"}},
Signs user out closing and deleting session.
Examples
iex> Eli.sign_out("JWT session token")
200
%{"data" => %{"message" => "signed out successfully"}}
404
%{"errors" => %{"detail" => "Not Found"}}
Checks whether the user is signed in or not.
Examples
iex> Eli.signed_in("JWT session token")
:signed_in
true
false
Unlocks user for making the he/she able to sign in again.
Examples
iex> Eli.unlock("Unlock token")
202
%{"data" => %{"message" => "account was successfully unlocked"}}
404
%{"errors" => %{"detail" => "Not Found"}}
Resend email for account confirmation.
Examples
iex> passwords = %{current_password: "Secret.123", new_password: "NewSecret.1234", new_password_confirmation: "NewSecret.1234"}
iex> Eli.resend_account_confirmation_email(JWT session token", password)
200
%{"data" => %{"message" => "password was successfully changed"}}
400 or 404
%{"errors" => %{"detail" => "Error message"}}